import axios from 'axios';
// Заменяем заглушки на импорт реальных типов
import { CalculationCreate, CalculationRead } from '../types';

// URL вашего FastAPI бэкенда
// Убедитесь, что порт совпадает с тем, на котором запущен uvicorn (по умолчанию 8000)
const API_BASE_URL = import.meta.env.VITE_API_URL || 'http://localhost:8000';

const apiClient = axios.create({
  baseURL: API_BASE_URL,
  headers: {
    'Content-Type': 'application/json',
  },
});

/**
 * Запускает новый расчет
 * @param data Входные параметры для расчета
 * @returns Данные созданного расчета
 */
// Используем импортированные типы
export const runCalculation = async (data: CalculationCreate): Promise<CalculationRead> => {
  try {
    // Указываем тип ответа
    const response = await apiClient.post<CalculationRead>('/calculation/', data);
    return response.data;
  } catch (error) {
    console.error("Error running calculation:", error);
    throw error;
  }
};

/**
 * Получает детали конкретного расчета по ID
 * @param id ID расчета
 * @returns Данные расчета
 */
// Используем импортированные типы
export const getCalculationById = async (id: number): Promise<CalculationRead> => {
  try {
    // Указываем тип ответа
    const response = await apiClient.get<CalculationRead>(`/calculation/${id}`);
    return response.data;
  } catch (error) {
    console.error(`Error fetching calculation ${id}:`, error);
    throw error;
  }
};

/**
 * Получает историю расчетов
 * @param skip Смещение для пагинации
 * @param limit Лимит записей на страницу
 * @returns Список расчетов
 */
// Используем импортированные типы
export const getCalculationHistory = async (skip: number = 0, limit: number = 100): Promise<CalculationRead[]> => {
  try {
    // Указываем тип ответа
    const response = await apiClient.get<CalculationRead[]>(`/calculation/history/?skip=${skip}&limit=${limit}`);
    return response.data;
  } catch (error) {
    console.error("Error fetching calculation history:", error);
    throw error;
  }
};

export default apiClient; 