import React from 'react';
import { LayoutPiece } from '../../types'; // Импортируем тип
import styles from './LayoutVisualizer.module.css';

const LayoutVisualizer: React.FC<{ layout: LayoutPiece[] | undefined | null}> = ({ layout }) => {
    if (!layout || !Array.isArray(layout) || layout.length === 0) {
        return <p className={styles.noData}>Данные раскроя отсутствуют или некорректны.</p>;
    }

    // Адаптивный viewBox
    const PADDING = 10;
    const maxX = Math.max(...layout.map(p => p.x + p.width)) + PADDING;
    const maxY = Math.max(...layout.map(p => p.y + p.height)) + PADDING;
    // Сохраняем соотношение сторон, если нужно, или используем фиксированную высоту/ширину
    const viewBoxWidth = maxX || 200; // Fallback width
    const viewBoxHeight = maxY || 200; // Fallback height


    return (
        <div className={styles.container}>
            <h4>Визуализация раскроя</h4>
            <svg
              className={styles.svgCanvas}
              width="100%"
              // preserveAspectRatio="xMidYMid meet" // Сохранять пропорции
              viewBox={`0 0 ${viewBoxWidth} ${viewBoxHeight}`}
            >
                {/* Можно добавить фон листа, если известны его размеры */}
                {/* <rect x="0" y="0" width={sheetWidth} height={sheetHeight} fill="#eee" /> */}
                {layout.map((piece) => (
                    <g key={piece.piece_id} className={styles.pieceGroup}>
                        <rect
                            x={piece.x}
                            y={piece.y}
                            width={piece.width}
                            height={piece.height}
                            className={styles.pieceRect}
                        />
                        <text
                            x={piece.x + piece.width / 2}
                            y={piece.y + piece.height / 2}
                            className={`${styles.pieceText} ${styles.pieceId}`}
                        >
                            {piece.piece_id}
                        </text>
                        <text
                            x={piece.x + 5}
                            y={piece.y + 15} // Немного опустим текст размера
                            className={`${styles.pieceText} ${styles.pieceSize}`}
                        >
                            {piece.width}x{piece.height}
                        </text>
                    </g>
                ))}
            </svg>
        </div>
    );
};

export default LayoutVisualizer; 